@@ -1,5 +1,5 @@
 (*
- * Copyright 2007 Samuel Mimram
+ * Copyright 2007-2011 Savonet team
  *
  * This file is part of ocaml-ogg.
  *
@@ -24,7 +24,7 @@
  * your choice, without any of the additional requirements listed in clause 6
  * of the GNU Library General Public License.
  * By "a publicly distributed version of the Library", we mean either the unmodified
- * Library as distributed by INRIA, or a modified version of the Library that is
+ * Library as distributed by The Savonet Team, or a modified version of the Library that is
  * distributed under the conditions defined in clause 3 of the GNU Library General
  * Public License. This exception does not however invalidate any other reasons why
  * the executable file might be covered by the GNU Library General Public License.
@@ -40,6 +40,7 @@
 exception Not_enough_data
 exception Bad_data
 exception Out_of_sync
+exception End_of_stream
 
 (**
   * The [page] struct encapsulates the data for an Ogg page.
@@ -137,14 +138,24 @@ sig
   (** 
     * Read a page from [Sync.t] 
     *
-    * Raises [Not_enough_data] if the reading function returned an empty string. *)
+    * Raises [End_of_stream] if the reading function returned an empty string. 
+    * Raises [Out_of_sync] if data is not synced and some byte where skiped. *)
   val read : t -> Page.t
 
   (** 
-    * This function is used to reset the internal counters of the [Sync.t] to initial values.
+    * This function is used to reset the internal counters of the 
+    * [Sync.t] to initial values. 
     *
     * [read_func] is optional and is a new function to read new data. *)
   val reset : ?read_func:(int -> string*int) -> t -> unit
+
+  (** 
+    * This function synchronizes the ogg_sync_state struct to the next ogg_page.
+    * 
+    * This is useful when seeking within a bitstream. page_seek will synchronize 
+    * to the next page in the bitstream and return information about how many bytes 
+    * we advanced or skipped in order to do so. *)
+  val seek : t -> Page.t
 end
 
 
@@ -212,10 +223,8 @@ sig
     *
     * Raises [Not_enough_data] if more data is needed and another page should be submitted.
     *
-    * Raises [Out_of_sync]  if we are out of sync and there is a gap in the data
-    *
-    * [sync] is a reference to a boolean set to true if the stream had a gap. *)
-  val get_packet : ?sync:(bool ref) -> stream -> packet
+    * Raises [Out_of_sync]  if we are out of sync and there is a gap in the data. *)
+  val get_packet : stream -> packet
 
   (**
     * This function assembles a data packet for output
@@ -226,6 +235,21 @@ sig
     * Raises [Out_of_sync]  if we are out of sync and there is a gap in the data *)
   val peek_packet : stream -> packet
 
+  (** This function picks up the granule position
+    * of the next packet in the stream without advancing it.
+    *
+    * Raises [Not_enough_data] if more data is needed and another page should be submitted.
+    *
+    * Raises [Out_of_sync]  if we are out of sync and there is a gap in the data *)
+  val peek_granulepos : stream -> Int64.t
+
+  (** This function discards the next packet in the stream.
+    *
+    * Raises [Not_enough_data] if more data is needed and another page should be submitted.
+    *
+    * Raises [Out_of_sync]  if we are out of sync and there is a gap in the data *)
+  val skip_packet : stream -> unit
+
   (**
     * This function submits a packet to the bitstream for page encapsulation. 
     * After this is called, more packets can be submitted, or pages can be written out.
@@ -248,6 +272,9 @@ sig
     *)
   val flush_page : stream -> Page.t
 
+  (** Returns a packet's granule position. *)
+  val packet_granulepos : packet -> Int64.t
+
   (** Backward compatibility *)
 
   type t = stream
